package org.apache.bcel.classfile;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import org.apache.bcel.classfile.Attribute;
import org.apache.bcel.classfile.ConstantPool;
import org.apache.bcel.classfile.Utility;
import org.apache.bcel.classfile.Visitor;

public final class Unknown extends Attribute {
  private static final org.apache.bcel.classfile.Unknown[] EMPTY_ARRAY = new org.apache.bcel.classfile.Unknown[0];
  
  private static final Map<String, org.apache.bcel.classfile.Unknown> UNKNOWN_ATTRIBUTES = new HashMap<>();
  
  private byte[] bytes;
  
  private final String name;
  
  static org.apache.bcel.classfile.Unknown[] getUnknownAttributes() {
    try {
      return (org.apache.bcel.classfile.Unknown[])UNKNOWN_ATTRIBUTES.values().toArray((Object[])EMPTY_ARRAY);
    } finally {
      UNKNOWN_ATTRIBUTES.clear();
    } 
  }
  
  public Unknown(int nameIndex, int length, byte[] bytes, ConstantPool constantPool) {
    super((byte)-1, nameIndex, length, constantPool);
    this.bytes = bytes;
    this.name = constantPool.getConstantUtf8(nameIndex).getBytes();
    UNKNOWN_ATTRIBUTES.put(this.name, this);
  }
  
  Unknown(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
    this(nameIndex, length, (byte[])null, constantPool);
    if (length > 0) {
      this.bytes = new byte[length];
      input.readFully(this.bytes);
    } 
  }
  
  public Unknown(org.apache.bcel.classfile.Unknown c) {
    this(c.getNameIndex(), c.getLength(), c.getBytes(), c.getConstantPool());
  }
  
  public void accept(Visitor v) {
    v.visitUnknown(this);
  }
  
  public Attribute copy(ConstantPool constantPool) {
    org.apache.bcel.classfile.Unknown c = (org.apache.bcel.classfile.Unknown)clone();
    if (this.bytes != null)
      c.bytes = (byte[])this.bytes.clone(); 
    c.setConstantPool(constantPool);
    return c;
  }
  
  public void dump(DataOutputStream file) throws IOException {
    super.dump(file);
    if (getLength() > 0)
      file.write(this.bytes, 0, getLength()); 
  }
  
  public byte[] getBytes() {
    return this.bytes;
  }
  
  public String getName() {
    return this.name;
  }
  
  public void setBytes(byte[] bytes) {
    this.bytes = bytes;
  }
  
  public String toString() {
    String hex;
    if (getLength() == 0 || this.bytes == null)
      return "(Unknown attribute " + this.name + ")"; 
    int limit = 10;
    if (getLength() > 10) {
      byte[] tmp = Arrays.copyOf(this.bytes, 10);
      hex = Utility.toHexString(tmp) + "... (truncated)";
    } else {
      hex = Utility.toHexString(this.bytes);
    } 
    return "(Unknown attribute " + this.name + ": " + hex + ")";
  }
}
